function checkupdate_ef(opt)
%CHECKUPDATE_EF  Check for update for Ezyfit
%   CHECKUPDATE_EF connects on the EzyFit webpage and checks for a new
%   version.
%   CHECKUPDATE_EF('dialog') does the same, but outputs the result in
%   a dialog box.
%
%   CHECKUPDATE_EF is automatically called at each Matlab restart if the
%   EzyFit menu is installed (see EFMENU).
%
%   See also ABOUT_EF, EFMENU. 

%   F. Moisy, moisy_at_fast.u-psud.fr
%   Revision: 1.02,  Date: 2006/04/10
%   This function is part of the EzyFit Toolbox

% History:
% 2005/12/12: v1.00, first version.
% 2006/01/12: v1.01, opens a new web browser.
% 2006/04/10: v1.02, Toolbox renamed 'EzyFit'.

verb=0;  % verbose mode

if ~exist('opt','var'), opt='command'; end;

v1=ver('ezyfit');  curv=str2double(v1.Version);

[s,res]=urlread('http://www.fast.u-psud.fr/ezyfit/index.html');
if ~res
    if strcmp(opt,'command')
        if verb, disp('Server unavailable.'); end;
        return;
    else
        helpdlg('Server unavailable','Check for update');
        return;
    end;
end;

p=strfind(s,'Version'); p=p(1);
if length(p),
    p1=strfind(s(p:end),' '); p1=p1(1);
    p2=strfind(s((p+p1):end),' '); p2=p2(1);
    vstr=s((p+p1-1):(p+p1+p2-1));
    newv=str2double(vstr);
else
    if verb, disp('Wrong file format on server'); end;
    return;
end;

if newv>curv,
    if strcmp(opt,'command')
        disp('A new version of EzyFit is available online.');
        disp('Click <a href="matlab:web http://www.fast.u-psud.fr/ezyfit -browser">here</a> to connect.');
    else
        button = questdlg('A new version of EzyFit is available online.','Check for update','Go online','Cancel','Go online');
        if strcmp(button,'Go online'),
            web http://www.fast.u-psud.fr/ezyfit -browser
        else
            return;
        end;
    end;
elseif newv<curv,
    if strcmp(opt,'command')
        if verb, disp('The online version is older than yours!'); end;
    else
        helpdlg('The online version is older than yours!','Check for update');
    end;
else
    if strcmp(opt,'command')
        if verb, disp('No new version available online'); end;
    else
        helpdlg('No new version available online','Check for update');
    end;
end;
