function dispeqfit(f)
%DISPEQFIT   Display the equation of a fit.
%   DISPEQFIT(F) displays the equation of the fit F in the command window,
%   using the settings defined in FITPARAM. The fit structure F is
%   obtained from FIT. By default, DISPEQFIT is automatically called from
%   FIT when no output argument is specified.
%
%   Example:
%      plotsample('power')
%      f = fit('alpha/x^n');
%      dispeqfit(f);
%
%   See also FITPARAM, FIT, SHOWFIT, SELECTFIT, SHOWEQBOX

%   F. Moisy, moisy_at_fast.u-psud.fr
%   Revision: 1.10,  Date: 2006/02/13
%   This function is part of the EzyFit Toolbox

% History:
% 2006/02/08: v1.00, first version.
% 2006/02/13: v1.10, compatible with 'y(x)=..' (free function name)


if exist('fitparam.m','file'),
    fp=fitparam;
else
    error('No fitparam file found.');
end;

streq = f.eq;
if strcmp(fp.eqdisplaymode,'replace'),
    for n=1:length(f.m),
        streq = strrep(streq, f.param{n}, num2str(f.m(n), fp.numberofdigit));
    end;
    streq = strrep(streq,'+-','-');
    disp(['Equation: ' f.yvar '(' f.xvar ') = ' streq]);
else    
    disp(['Equation: ' f.yvar '(' f.xvar ') = ' streq]);
    for i=1:length(f.m),
        disp([ '     ' f.param{i} ' = ' num2str(f.m(i), fp.numberofdigit)]);
    end;
end;

lastline='';
switch lower(fp.corrcoefmode),
    case 'r', lastline=['R = ' num2str(f.r, fp.numberofdigit) '  '];
    case 'r2', lastline=['R^2 = ' num2str(f.r^2, fp.numberofdigit) '  '];
end;
if strcmp(fp.linlogdisp,'on');
    lastline=[lastline '(' f.fitmode ')'];
end;
if length(lastline),
    disp(['     ' lastline]);
end;
